@@ -680,7 +680,9 @@ def MWW(X,y, verbose = False, show = False, max_plot_num = 5):
 
         Xcis = np.array(Xcis)         
         
-        if np.allclose(Xcis[0], Xcis[1]): # ValueError: All numbers are identical in mannwhitneyu
+        # Special case for ValueError: All numbers are identical in mannwhitneyu
+        # Don't use np.allclose(Xcis[0], Xcis[1]) as the lengths may differ
+        if len( set (list(Xcis[0]) + list(Xcis[1]) ) ) == 1: 
             U = len(Xcis[0]) * len(Xcis[1]) / 2 # return the theoretical U max: n1*n2/2
             p = 1 # theoretical max. SPSS will return p = 1.0 for identical samples.
         else:
